#import <Foundation/Foundation.h>
#import "SWGScreenshot.h"
#import "SWGScreenshotError.h"
#import "SWGScreenshotHost.h"
#import "SWGScreenshotInfoError.h"
#import "SWGScreenshotList.h"
#import "SWGScreenshotShort.h"
#import "SWGApi.h"

/**
* Browshot API
* Take screenshots of any website in real time
*
* OpenAPI spec version: 1.16.0
* Contact: support@browshot.com
*
* NOTE: This class is auto generated by the swagger code generator program.
* https://github.com/swagger-api/swagger-codegen.git
* Do not edit the class manually.
*/



@interface SWGScreenshotApi: NSObject <SWGApi>

extern NSString* kSWGScreenshotApiErrorDomain;
extern NSInteger kSWGScreenshotApiMissingParamErrorCode;

+(instancetype) sharedAPI;

/// Request a screenshot
/// Screenshots requests to private and shared instances require a positive balance.  *IMPORTANT*: Remember that you can only do 100 free screenshots per month. To used a premium instance, use instance_id=65 for example. 
///
/// @param url URL of the page to get a screenshot for
/// @param instanceId instance ID to use
/// @param size screenshot size - \"screen\" (default) or \"page\" (optional) (default to screen)
/// @param cache use a previous screenshot (same URL, same instance) if it was done within <cache_value> seconds. The default value is 24hours. Specify cache=0 if you want a new screenshot. (optional) (default to 86400)
/// @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay=0 to take screenshots faster. (optional) (default to 5)
/// @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay=0 to take screenshots faster. (optional) (default to 10)
/// @param screenWidth width of the browser window. For desktop browsers only. (optional) (default to 1024)
/// @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) (optional) (default to 768)
/// @param priority assign priority to the screenshot (for private instances only) (optional)
/// @param referer use a custom referrer header - paid screenshots only (optional)
/// @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only (optional)
/// @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only (optional)
/// @param script URL of javascript file to execute after the page load event (optional)
/// @param details level of information available with screenshot/info (optional) (default to 2)
/// @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. (optional) (default to 0)
/// @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 = disabled) (optional) (default to 0)
/// @param headers any custom HTTP headers. (Not supported with Internet Explorer) (optional)
/// @param shots take multiple screenshots of the same page. This costs 1 additional credit for every 2 additional screenshots. (optional) (default to 1)
/// @param shotInterval number of seconds between 2 screenshots (optional) (default to 5)
/// @param hosting hosting option - s3 or browshot (optional)
/// @param hostingHeight maximum height of the thumbnail to host (optional)
/// @param hostingWidth maximum height of the thumbnail to host (optional)
/// @param hostingScale scale of the thumbnail to host (optional) (default to 1)
/// @param hostingBucket S3 bucket to upload the screenshot or thumbnail (required for S3) (optional)
/// @param hostingFile file name to use (for S3 only) (optional)
/// @param hostingHeaders list of headers to add to the S3 object (for S3 only) (optional)
///  code:200 message:"Request accepted",
///  code:403 message:"Error"
/// @return SWGScreenshot*
-(NSNumber*) screenshotCreateGetWithUrl: (NSString*) url
    instanceId: (NSNumber*) instanceId
    size: (NSString*) size
    cache: (NSNumber*) cache
    delay: (NSNumber*) delay
    flashDelay: (NSNumber*) flashDelay
    screenWidth: (NSNumber*) screenWidth
    screenHeight: (NSNumber*) screenHeight
    priority: (NSNumber*) priority
    referer: (NSString*) referer
    postData: (NSString*) postData
    cookie: (NSString*) cookie
    script: (NSString*) script
    details: (NSNumber*) details
    html: (NSNumber*) html
    maxWait: (NSNumber*) maxWait
    headers: (NSString*) headers
    shots: (NSNumber*) shots
    shotInterval: (NSNumber*) shotInterval
    hosting: (NSString*) hosting
    hostingHeight: (NSNumber*) hostingHeight
    hostingWidth: (NSNumber*) hostingWidth
    hostingScale: (NSNumber*) hostingScale
    hostingBucket: (NSString*) hostingBucket
    hostingFile: (NSString*) hostingFile
    hostingHeaders: (NSString*) hostingHeaders
    completionHandler: (void (^)(SWGScreenshot* output, NSError* error)) handler;

/// Delete screenshot data
/// You can delete details of your screenshots to remove any confidential information. 
///
/// @param _id screenshot ID
/// @param data data to remove. You can specify multiple of them (separated by a ,): *image* (image files), *url* (url requested), *metadata* (time added, time finished, post data, cookie and referer used for the screenshot), *all* (all data and files)  (optional) (default to image)
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotShort>*
-(NSNumber*) screenshotDeleteGetWithId: (NSNumber*) _id
    data: (NSString*) data
    completionHandler: (void (^)(NSArray<SWGScreenshotShort>* output, NSError* error)) handler;

/// Host thumbnails on your own S3 account or on Browshot.
/// You can host screenshots and thumbnails on your own S3 account or on Browshot.
///
/// @param _id screenshot ID
/// @param hosting hosting option: s3 or browshot
/// @param width width of the thumbnail (optional)
/// @param height height of the thumbnail (optional)
/// @param scale scale of the thumbnail (optional) (default to 1)
/// @param bucket S3 bucket to upload the screenshot or thumbnail - required with hosting=s3 (optional)
/// @param file file name to use - optional, used with hosting=s3 (optional)
/// @param headers HTTP headers to add to your S3 object - optional, used with hosting=s3 (optional)
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotHost>*
-(NSNumber*) screenshotHostGetWithId: (NSNumber*) _id
    hosting: (NSString*) hosting
    width: (NSNumber*) width
    height: (NSNumber*) height
    scale: (NSNumber*) scale
    bucket: (NSString*) bucket
    file: (NSString*) file
    headers: (NSString*) headers
    completionHandler: (void (^)(NSArray<SWGScreenshotHost>* output, NSError* error)) handler;

/// Get the HTML code
/// Retrieve the HTML code of the rendered page. This API call should be used when html=1 was specified in the screenshot request. 
///
/// @param _id screenshot ID
///  code:0 message:"HTML code"
-(NSNumber*) screenshotHtmlGetWithId: (NSNumber*) _id
    completionHandler: (void (^)(NSError* error)) handler;

/// Query screenshot status
/// Once a screenshot has been requested, its status must be checked until it is either \"error\" or \"finished\".
///
/// @param _id screenshot ID received from /api/v1/screenshot/create
/// @param details level of details about the screenshot and the page (optional) (default to 2)
///  code:200 message:"Screenshot found",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshot>*
-(NSNumber*) screenshotInfoGetWithId: (NSNumber*) _id
    details: (NSNumber*) details
    completionHandler: (void (^)(NSArray<SWGScreenshot>* output, NSError* error)) handler;

/// Get information about the last 100 screenshots requested.
/// Get information about the last 100 screenshots requested.
///
/// @param limit maximum number of screenshots' information to return (optional) (default to 100)
/// @param status get list of screenshot in a given status (error, finished, in_process) (optional)
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotList>*
-(NSNumber*) screenshotListGetWithLimit: (NSNumber*) limit
    status: (NSString*) status
    completionHandler: (void (^)(NSArray<SWGScreenshotList>* output, NSError* error)) handler;

/// Request multiple screenshots
/// Request multiple screenshots in one API call. The API call accepts all the parameters supported by screenshot/create. You can specify up to 10 URLs and 10 instances for a total of 100 screenshots in one API call. 
///
/// @param url URL of the page to get a screenshot for. You can specify multiple url parameters (up to 10).
/// @param instanceId instance ID to use. You can specify multiple instance_id parameters (up to 10).
/// @param size screenshot size - \"screen\" (default) or \"page\" (optional) (default to screen)
/// @param cache use a previous screenshot (same URL, same instance) if it was done within <cache_value> seconds. The default value is 24hours. Specify cache=0 if you want a new screenshot. (optional) (default to 86400)
/// @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay=0 to take screenshots faster. (optional) (default to 5)
/// @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay=0 to take screenshots faster. (optional) (default to 10)
/// @param screenWidth width of the browser window. For desktop browsers only. (optional) (default to 1024)
/// @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) (optional) (default to 768)
/// @param priority assign priority to the screenshot (for private instances only) (optional)
/// @param referer use a custom referrer header - paid screenshots only (optional)
/// @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only (optional)
/// @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only (optional)
/// @param script URL of javascript file to execute after the page load event (optional)
/// @param details level of information available with screenshot/info (optional) (default to 2)
/// @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. (optional) (default to 0)
/// @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 = disabled) (optional) (default to 0)
/// @param headers any custom HTTP headers. (Not supported with Internet Explorer) (optional)
/// @param hosting hosting option - s3 or browshot (optional)
/// @param hostingHeight maximum height of the thumbnail to host (optional)
/// @param hostingWidth maximum height of the thumbnail to host (optional)
/// @param hostingScale scale of the thumbnail to host (optional) (default to 1)
/// @param hostingBucket S3 bucket to upload the screenshot or thumbnail (required for S3) (optional)
/// @param hostingFile file name to use (for S3 only) (optional)
/// @param hostingHeaders list of headers to add to the S3 object (for S3 only) (optional)
///  code:200 message:"Request accepted",
///  code:403 message:"Error"
/// @return SWGScreenshotList*
-(NSNumber*) screenshotMultipleGetWithUrl: (NSString*) url
    instanceId: (NSNumber*) instanceId
    size: (NSString*) size
    cache: (NSNumber*) cache
    delay: (NSNumber*) delay
    flashDelay: (NSNumber*) flashDelay
    screenWidth: (NSNumber*) screenWidth
    screenHeight: (NSNumber*) screenHeight
    priority: (NSNumber*) priority
    referer: (NSString*) referer
    postData: (NSString*) postData
    cookie: (NSString*) cookie
    script: (NSString*) script
    details: (NSNumber*) details
    html: (NSNumber*) html
    maxWait: (NSNumber*) maxWait
    headers: (NSString*) headers
    hosting: (NSString*) hosting
    hostingHeight: (NSNumber*) hostingHeight
    hostingWidth: (NSNumber*) hostingWidth
    hostingScale: (NSNumber*) hostingScale
    hostingBucket: (NSString*) hostingBucket
    hostingFile: (NSString*) hostingFile
    hostingHeaders: (NSString*) hostingHeaders
    completionHandler: (void (^)(SWGScreenshotList* output, NSError* error)) handler;

/// Search for screenshots of a specific URL.
/// Search for screenshots of a specific URL.
///
/// @param url look for a string matching the URL requested
/// @param limit maximum number of screenshots' information to return (optional) (default to 50)
/// @param status get list of screenshot in a given status (error, finished, in_process) (optional)
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotList>*
-(NSNumber*) screenshotSearchGetWithUrl: (NSString*) url
    limit: (NSNumber*) limit
    status: (NSString*) status
    completionHandler: (void (^)(NSArray<SWGScreenshotList>* output, NSError* error)) handler;

/// Share a screenshot
/// You can make your screenshots public, add notes, and share it with your friends and colleagues. Only screenshots which are successfully completed can be shared.n the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 
///
/// @param _id screenshot ID
/// @param note note to add on the sharing page (optional)
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotHost>*
-(NSNumber*) screenshotShareGetWithId: (NSNumber*) _id
    note: (NSString*) note
    completionHandler: (void (^)(NSArray<SWGScreenshotHost>* output, NSError* error)) handler;

/// Retrieve a thumbnail image
/// Unlike the other API calls, this API sends back the thumbnail as a PNG file, not JSON. The HTTP response code indicates whether the screenshot was successful (200), or incomplete (404) or failed (404). If the screenshot failed or is not finished, a default image \"Not found\" is sent.  You can crop your screenshots. The crop is done first, then the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 
///
/// @param _id screenshot ID
/// @param width width of the thumbnail (optional)
/// @param height height of the thumbnail (optional)
/// @param scale scale of the thumbnail (optional) (default to 1)
/// @param zoom zoom 1 to 100 percent (optional) (default to 100)
/// @param ratio Use fit to keep the original page ration, and fill to get a thumbnail for the exact width and height.  specified. If you provide both width and height, you need to specify the ratio: fit to keep the original width/height ratio (the thumbnail might be smaller than the specified width and height), or fill to crop the image if necessary. (optional) (default to fit)
/// @param left left edge of the area to be cropped (optional) (default to 0)
/// @param right right edge of the area to be cropped (optional) (default to 0)
/// @param top top edge of the area to be cropped (optional) (default to 0)
/// @param bottom bottom edge of the area to be cropped (optional)
/// @param format image as PNG or JPEG (optional) (default to png)
/// @param shot get the second or third screenshot if multiple screenshots were requested (optional) (default to 1)
/// @param quality JPEG quality factor (for JPEG thumbnails only) (optional) (default to 100)
///  code:200 message:"thumbnail",
///  code:404 message:"Screenshot not found"
-(NSNumber*) screenshotThumbnailGetWithId: (NSNumber*) _id
    width: (NSNumber*) width
    height: (NSNumber*) height
    scale: (NSNumber*) scale
    zoom: (NSNumber*) zoom
    ratio: (NSString*) ratio
    left: (NSNumber*) left
    right: (NSNumber*) right
    top: (NSNumber*) top
    bottom: (NSNumber*) bottom
    format: (NSString*) format
    shot: (NSNumber*) shot
    quality: (NSNumber*) quality
    completionHandler: (void (^)(NSError* error)) handler;


@end
